#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2014 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
"""
Unit tests for schooltool.encinitas.generations.evolve1
"""
import unittest
import doctest

from transaction import abort
from zope.app.testing import setup
from zope.component import provideAdapter

from schooltool.basicperson.demographics import getDemographicsFields
from schooltool.testing.setup import getIntegrationTestZCML
from schooltool.testing.stubs import AppStub


def doctest_evolve1():
    """Evolution to generation 1.

        >>> from schooltool.generations.tests import ContextStub
        >>> context = ContextStub(app)

    The Alert Comment field is not in the original demographics fields:

        >>> from schooltool.basicperson.interfaces import IDemographicsFields
        >>> 'alert_comment' in IDemographicsFields(app)
        False

    Evolve the application:

        >>> from schooltool.encinitas.generations.evolve1 import evolve
        >>> evolve(context)

    The Alert Comment field has been added as a limited field for students:

        >>> 'alert_comment' in IDemographicsFields(app)
        True
        >>> field = IDemographicsFields(app)['alert_comment']
        >>> field.title
        u'Alert Comment'
        >>> field.limit_keys
        ['students']

    """


def setUp(test):
    setup.placefulSetUp()
    zcml = getIntegrationTestZCML()
    zcml.include('schooltool.schoolyear', file='schoolyear.zcml')
    zcml.string('''
    <adapter
      factory="schooltool.basicperson.demographics.DemographicsInit"
      name="schooltool.basicperson.demographics" />
    ''')
    provideAdapter(getDemographicsFields)
    app = AppStub()
    test.globs.update({
        'app': app,
        })


def tearDown(test):
    setup.placefulTearDown()
    abort()


def test_suite():
    return unittest.TestSuite([
        doctest.DocTestSuite(setUp=setUp, tearDown=tearDown,
                             optionflags=(doctest.ELLIPSIS |
                                          doctest.NORMALIZE_WHITESPACE |
                                          doctest.REPORT_ONLY_FIRST_FAILURE))
    ])


if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
